@@ -44,6 +44,9 @@ class MemoryServer:
     def NoSessions(self) -> bool:
         return len(self.__sessions) == 0
 
+    def NoData(self) -> bool:
+        return len(self.__blocks) == 0
+
     def GetData(self, timeout: float = 1.0) -> Tuple[int, bytes]:
         seq, b = -1, None
         tCreate = None
